@@ -17,14 +17,16 @@ namespace KWayland
 {
 namespace Client
 {
-class BlurManager;
-class ContrastManager;
 class Compositor;
 class ConnectionThread;
+}
+}
+
+class BlurManager;
 class Blur;
+class ContrastManager;
 class Contrast;
-}
-}
+class SlideManager;
 
 class WindowEffects : public QObject, public KWindowEffectsPrivateV2
 {
@@ -41,14 +43,11 @@ public:
 
     bool isEffectAvailable(KWindowEffects::Effect effect) override;
     void slideWindow(WId id, KWindowEffects::SlideFromLocation location, int offset) override;
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 81)
     QList<QSize> windowSizes(const QList<WId> &ids) override;
-#endif
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
+
     void presentWindows(WId controller, const QList<WId> &ids) override;
     void presentWindows(WId controller, int desktop = NET::OnAllDesktops) override;
     void highlightWindows(WId controller, const QList<WId> &ids) override;
-#endif
     void enableBlurBehind(WId winId, bool enable = true, const QRegion &region = QRegion()) override;
     void enableBackgroundContrast(WId winId,
                                   bool enable = true,
@@ -56,17 +55,16 @@ public:
                                   qreal intensity = 1,
                                   qreal saturation = 1,
                                   const QRegion &region = QRegion()) override;
-    void setBackgroundFrost(QWindow *window, QColor color, const QRegion &region = QRegion()) override;
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 67)
     void markAsDashboard(WId window) override;
-#endif
+    void setBackgroundFrost(QWindow *window, QColor color, const QRegion &region = QRegion()) override;
+
 private:
     void installContrast(QWindow *window, bool enable = true, qreal contrast = 1, qreal intensity = 1, qreal saturation = 1, const QRegion &region = QRegion());
     void installBlur(QWindow *window, bool enable, const QRegion &region);
     void installSlide(QWindow *window, KWindowEffects::SlideFromLocation location, int offset);
 
-    void resetBlur(QWindow *window, KWayland::Client::Blur *blur = nullptr);
-    void resetContrast(QWindow *window, KWayland::Client::Contrast *contrast = nullptr);
+    void resetBlur(QWindow *window, Blur *blur = nullptr);
+    void resetContrast(QWindow *window, Contrast *contrast = nullptr);
 
     QHash<QWindow *, QList<QMetaObject::Connection>> m_windowWatchers;
     QHash<QWindow *, QRegion> m_blurRegions;
@@ -77,13 +75,16 @@ private:
         QRegion region;
     };
     QHash<QWindow *, BackgroundContrastData> m_backgroundConstrastRegions;
-    QHash<QWindow *, QPointer<KWayland::Client::Blur>> m_blurs;
-    QHash<QWindow *, QPointer<KWayland::Client::Contrast>> m_contrasts;
+    QHash<QWindow *, QPointer<Blur>> m_blurs;
+    QHash<QWindow *, QPointer<Contrast>> m_contrasts;
     struct SlideData {
         KWindowEffects::SlideFromLocation location;
         int offset;
     };
     QHash<QWindow *, SlideData> m_slideMap;
+    BlurManager *m_blurManager;
+    ContrastManager *m_contrastManager;
+    SlideManager *m_slideManager;
 };
 
 #endif
