@@ -170,12 +170,14 @@ int WindowSystem::currentDesktop()
     return 0;
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 101)
 void WindowSystem::demandAttention(WId win, bool set)
 {
     Q_UNUSED(win)
     Q_UNUSED(set)
     qCDebug(KWAYLAND_KWS) << "This plugin does not support demanding attention";
 }
+#endif
 
 QString WindowSystem::desktopName(int desktop)
 {
@@ -192,12 +194,14 @@ QPoint WindowSystem::desktopToViewport(int desktop, bool absolute)
     return QPoint();
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 WId WindowSystem::groupLeader(WId window)
 {
     Q_UNUSED(window)
     qCDebug(KWAYLAND_KWS) << "This plugin does not support group leader";
     return 0;
 }
+#endif
 
 bool WindowSystem::icccmCompliantMappingState()
 {
@@ -319,6 +323,7 @@ void WindowSystem::setStrut(WId win, int left, int right, int top, int bottom)
     qCDebug(KWAYLAND_KWS) << "This plugin does not support window struts";
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 101)
 void WindowSystem::setIcons(WId win, const QPixmap &icon, const QPixmap &miniIcon)
 {
     Q_UNUSED(win)
@@ -326,6 +331,7 @@ void WindowSystem::setIcons(WId win, const QPixmap &icon, const QPixmap &miniIco
     Q_UNUSED(miniIcon)
     qCDebug(KWAYLAND_KWS) << "This plugin does not support setting window icons";
 }
+#endif
 
 void WindowSystem::setOnActivities(WId win, const QStringList &activities)
 {
@@ -549,12 +555,14 @@ QList<WId> WindowSystem::stackingOrder()
     return QList<WId>();
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 WId WindowSystem::transientFor(WId window)
 {
     Q_UNUSED(window)
     qCDebug(KWAYLAND_KWS) << "This plugin does not support transient for windows";
     return 0;
 }
+#endif
 
 int WindowSystem::viewportToDesktop(const QPoint &pos)
 {
